@@ -9,6 +9,7 @@ from gestionatr.input.messages import message
 from gestionatr.input.messages import message_gas
 from gestionatr.input.messages.message import except_f1
 from gestionatr.output.messages.sw_p0 import ENVELOP_BY_DISTR
+from gestionatr.exceptions import *
 
 from gestionatr import __version__
 
@@ -107,12 +108,13 @@ def request_p0(url, user, password, xml_str=None, params=None):
     retry_envelop = ENVELOP_BY_DISTR.get("reintent")
     error = None
     for envelop in [distri_envelop, retry_envelop]:
-        soap_content = envelop['template'].format(xml_str=xml_str)
+        xml_str_to_use = xml_str
+        soap_content = envelop['template'].format(xml_str=xml_str_to_use)
 
         # Send request
         h = headers.copy()
         h.update(envelop['extra_headers'])
-        res = requests.post(url, data=soap_content, headers=h)
+        res = requests.post(url, data=soap_content, headers=h, auth=(user, password))
         res = res.content
         try:
             def find_child(element, child_name):
@@ -129,9 +131,19 @@ def request_p0(url, user, password, xml_str=None, params=None):
             aux_res = find_child(aux, "MensajeEnvioInformacionPS")
             if aux_res is None:
                 aux_res = find_child(aux, "MensajeRechazoP0")
+            if aux_res is None:
+                aux_res = find_child(aux, "faultstring")
+                if aux_res is not None:
+                    error_mssg = {
+                        'request': res,
+                        'response': etree.tostring(aux_res)
+                    }
+                    raise P0FaultError(error_mssg)
 
             res = etree.tostring(aux_res)
             return res
+        except P0FaultError as p0efe:
+            raise
         except Exception as e:
             if not error:
                 error = e
